@@ -122,6 +122,7 @@ mmvmax=vmax
 mmwatershed=watershed
 
 gshow=overlay
+gdtshow=isolines
 
 # Functions which were removed:
 
@@ -655,3 +656,126 @@ def mmglblshow(X, border=0.0):
     b=resize(take(B, X.ravel() - mmin),X.shape)
     Y=concat('d',r,g,b)
     return Y
+
+
+def dtshow(f, n=10):
+    """
+        - Purpose
+            Display a distance transform image with an iso-line color table.
+        - Synopsis
+            y = dtshow(f, n=10)
+        - Input
+            f: Gray-scale (uint8 or uint16) image. Distance transform.
+            n: Boolean Default: 10. Number of iso-contours.
+        - Output
+            y: Gray-scale (uint8 or uint16) or binary image. Optionally
+               return RGB uint8 image
+        - Description
+            Displays the distance transform image f (uint8 or uint16) with a
+            special gray-scale color table with n pseudo-color equaly
+            spaced. The final appearance of this display is similar to an
+            iso-contour image display. The infinity value, which is the
+            maximum level allowed in the image, is displayed as black. The
+            image is displayed in the MATLAB figure only if no output
+            parameter is given.
+        - Examples
+            #
+            f=readgray('blob.tif')
+            fd=dist(f)
+            show(fd)
+            dtshow(fd)
+    """
+    import adpil
+
+    if (isbinary(f)) or (len(f.shape) != 2):
+      print 'Error, dtshow: works only for grayscale labeled image'
+      return
+    y=gdtshow(f, n)
+    adpil.adshow(y)
+
+def readgray(filename):
+    """
+        - Purpose
+            Read an image from a coercial file format and stores it as a
+            gray-scale image.
+        - Synopsis
+            y = readgray(filename)
+        - Input
+            filename: String Name of file to read.
+        - Output
+            y: Gray-scale (uint8 or uint16) or binary image.
+        - Description
+            readgray reads the image in filename and stores it in y , an
+            uint8 gray-scale image (without colormap). If the input file is
+            a color RGB image, it is converted to gray-scale using the
+            equation: y = 0.2989 R + 0.587 G + 0.114 B. This functions uses
+            de PIL module.
+        - Examples
+            #
+            a=readgray('cookies.tif')
+            show(a)
+    """
+    import adpil
+    import numpy
+
+    y = adpil.adread(filename)
+    if (len(y.shape) == 3) and (y.shape[0] == 3):
+       if numpy.alltrue(numpy.alltrue(y[0,:,:] == y[1,:,:] and
+                                          y[0,:,:] == y[2,:,:])):
+          y = y[0,:,:]
+       else:
+          print 'Warning: converting true-color RGB image to gray'
+          y = ubyte(0.2989 * y[0,:,:] + 
+                      0.5870 * y[1,:,:] + 
+                      0.1140 * y[2,:,:])
+    elif (len(y.shape) == 2):
+       pass
+    else:
+       raise ValueError, 'Error, it is not 2D image'
+    return y
+
+
+def lblshow(f, option='noborder'):
+    """
+        - Purpose
+            Display a labeled image assigning a random color for each label.
+        - Synopsis
+            y = lblshow(f, option='noborder')
+        - Input
+            f:      Gray-scale (uint8 or uint16) image. Labeled image.
+            option: String Default: 'noborder'. BORDER or NOBORDER: includes
+                    or not a white border around each labeled region
+        - Output
+            y: Gray-scale (uint8 or uint16) or binary image. Optionally
+               return RGB uint8 image
+        - Description
+            Displays the labeled image f (uint8 or uint16) with a pseudo
+            color where each label appears with a random color. The image is
+            displayed in the MATLAB figure only if no output parameter is
+            given.
+        - Examples
+            #
+            f=readgray('blob3.tif')
+            f1=label(f,sebox())
+            show(f1)
+            lblshow(f1)
+            lblshow(f1,'border')
+    """
+    import string
+    import adpil
+
+    if (isbinary(f)) or (len(f.shape) != 2):
+      print 'Error, lblshow: works only for grayscale labeled image'
+      return
+    option = string.upper(option);
+    if option == 'NOBORDER':
+      border = 0.0;
+    elif option == 'BORDER':
+      border = 1.0;
+    else:
+      print 'Error: option must be BORDER or NOBORDER'
+    y = randomcolor(f, border);
+    adpil.adshow(y)
+    return y
+
+
